==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/app/models/mail_delivery.rb <==
# -*- coding: utf-8 -*-
class MailDelivery < ActiveRecord::Base
  belongs_to :user
  belongs_to :order, :class_name => 'Order', :foreign_key => 'order_id'
  belongs_to :inquiry

  # サイト区分
  selectable_attr :site_div do
    entry '1', :jisha, '自社'
    entry '2', :rakuten, '楽天'
    entry '3', :yahoo, 'YAHOO'
  end

  selectable_attr :mail_div, :enum => MailTemplate.mail_type_div_enum

  # 検索条件生成
  def self.create_condition(condition, time_now = Time.now())
    where = Condition.block do |c|
      c.filter(:ignore_blank)
      # メール区分の条件
      c.and(:mail_div, condition.mail_div)
      # 配信日時Fromの条件
      c.and("mail_deliveries.deliveried_at", ">=", condition.deliveried_at_from_time)
      # 配信日時Toの条件
      c.and("mail_deliveries.deliveried_at", "<=", condition.deliveried_at_to_time)
      # 論理削除の条件
      c.and do |c4|
        c4.or("sql", "mail_deliveries.deleted_at IS NULL")
        c4.or('mail_deliveries.deleted_at', '>', time_now.strftime('%Y-%m-%d %H:%M:%S'))
      end
    end
  end

  # メール配信履歴インスタンス生成
  def self.create_front_mail_history(tmail, subject = nil, body = nil, user_id = nil, mail_div_key = :free, deliveried_at = Time.now)
    MailDelivery.new({
        :user_id => user_id,
        :mail_div => MailTemplate.mail_type_div_id_by_key(mail_div_key),
        :deliveried_at => deliveried_at,
        :header => "",
        :to_address => tmail.to.join(','),
        :from_address => tmail.from[0],
        :message_id => tmail.message_id,
        :subject => subject ? subject : NKF::nkf("-w", tmail.subject),
        :mail_body => body ? body : NKF::nkf("-w", tmail.body)
      })
  end

  # 検索条件生成（問合せ詳細画面用）
  def self.create_condition_for_inquiry(inquiry_id, time_now = Time.now)
    where = Condition.block do |c|
      c.filter(:ignore_blank)
      # メール区分の条件
      c.and do |mail_div_q|
        mail_div_q.or(:mail_div, MailTemplate.mail_type_div_id_by_key(:inquiry))
        mail_div_q.or(:mail_div, MailTemplate.mail_type_div_id_by_key(:reply))
      end
      # お問合せ番号の条件
      c.and(:inquiry_id, inquiry_id)
      # 論理削除の条件
      c.and do |c4|
        c4.or("sql", "mail_deliveries.deleted_at IS NULL")
        c4.or('mail_deliveries.deleted_at', '>', time_now.strftime('%Y-%m-%d %H:%M:%S'))
      end
    end
  end

  #
  # 検索フォーム
  #
  class SearchConditionForm < ActiveForm
    attr_accessor :mail_div, :deliveried_at_from, :deliveried_at_to, :disp_count, :inquiry_id

    # 日付フォーマット
    validates_format_of :deliveried_at_from, :with => /^\d{4}\/\d{1,2}\/\d{1,2}$/, :message => :EM070001, :if => :deliveried_at_from_unempty?
    validates_format_of :deliveried_at_to, :with => /^\d{4}\/\d{1,2}\/\d{1,2}$/, :message => :EM070001, :if => :deliveried_at_to_unempty?

    # deliveried_at_fromに値がある場合trueをかえします。
    def deliveried_at_from_unempty?
      !deliveried_at_from.blank?
    end

    # deliveried_at_toに値がある場合trueをかえします。
    def deliveried_at_to_unempty?
      !deliveried_at_to.blank?
    end

    # 日付の存在チェック
    def validate
      if deliveried_at_from_unempty?
        _date = deliveried_at_from.split('/')
        unless Date.exist?(_date[0].to_i, _date[1].to_i, _date[2].to_i)
          errors.add(:deliveried_at_from, :EM990007)
        end
      end
      if deliveried_at_to_unempty?
        _date = deliveried_at_to.split('/')
        unless Date.exist?(_date[0].to_i, _date[1].to_i, _date[2].to_i)
          errors.add(:deliveried_at_to, :EM990007)
        end
      end
    end

    # 日付をTime型に変換する（日付が指定されなければnilを返す）
    def deliveried_at_from_time
      return nil if deliveried_at_from.blank?
      start_time_str = "#{self.deliveried_at_from} 00:00:00"
      return Time.parse(start_time_str)
    end
    
    def deliveried_at_to_time
      return nil if deliveried_at_to.blank?
      end_time_str = "#{self.deliveried_at_to} 23:59:59"
      return Time.parse(end_time_str)
    end
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/app/models/mail_delivery.rb <==
# -*- coding: utf-8 -*-
class MailDelivery < ActiveRecord::Base
  belongs_to :user
  belongs_to :order, :class_name => 'Order', :foreign_key => 'order_id'
  belongs_to :inquiry

  # サイト区分
  selectable_attr :site_div do
    entry '1', :jisha, '自社'
    entry '2', :rakuten, '楽天'
    entry '3', :yahoo, 'YAHOO'
  end

  selectable_attr :mail_div, :enum => MailTemplate.mail_type_div_enum

  # 検索条件生成
  def self.create_condition(condition, time_now = Time.now())
    where = Condition.block do |c|
      c.filter(:ignore_blank)
      
      # 会員ユーザーコードの条件
      c.and("users.user_code", "like", "%#{condition.user_code}%")
      # 顧客区分の条件
      if condition.member_div == User.member_div_id_by_key(:no_membership)
        c.and do |c1|
          c1.or "users.member_div", condition.member_div
          c1.or "users.member_div IS NULL"
        end
      else
        c.and "users.member_div", condition.member_div
      end
      # 名前の条件
      c.and do |c1|
        _name = condition.name.gsub(' ', '').gsub('　', '') if condition.name
        c1.or "CONCAT(users.name_last, users.name_first)", "like", "%#{_name}%"
        c1.or "CONCAT(users.name_first, users.name_last)", "like", "%#{_name}%"
        c1.or "CONCAT(users.kana_name_last, users.kana_name_first)", "like", "%#{_name}%"
        c1.or "CONCAT(users.kana_name_first, users.kana_name_last)", "like", "%#{_name}%"
        c1.or "CONCAT(inquiries.name_last, inquiries.name_first)", "like", "%#{_name}%"
        c1.or "CONCAT(inquiries.name_first, inquiries.name_last)", "like", "%#{_name}%"
        c1.or "CONCAT(inquiries.kana_name_last, inquiries.kana_name_first)", "like", "%#{_name}%"
        c1.or "CONCAT(inquiries.kana_name_first, inquiries.kana_name_last)", "like", "%#{_name}%"
      end if condition.name && !(condition.name.empty?)
      # メールアドレスの条件
      c.and( "to_address", "like", "%#{condition.email}%")
      # メール区分の条件
      c.and(:mail_div, condition.mail_div)
      # 配信日時Fromの条件
      c.and("mail_deliveries.deliveried_at", ">=", condition.deliveried_at_from_time)
      # 配信日時Toの条件
      c.and("mail_deliveries.deliveried_at", "<=", condition.deliveried_at_to_time)
      # 論理削除の条件
      c.and do |c4|
        c4.or("sql", "mail_deliveries.deleted_at IS NULL")
        c4.or('mail_deliveries.deleted_at', '>', time_now.strftime('%Y-%m-%d %H:%M:%S'))
      end
    end
  end

  # メール配信履歴インスタンス生成
  def self.create_front_mail_history(tmail, subject = nil, body = nil, user_id = nil, mail_div_key = :free, deliveried_at = Time.now)
    to_address = tmail.to.is_a?(Array) ? tmail.to.join(',') : tmail.to
    MailDelivery.new({
        :user_id => user_id,
        :mail_div => MailTemplate.mail_type_div_id_by_key(mail_div_key),
        :deliveried_at => deliveried_at,
        :header => "",
        :to_address => to_address,
        :from_address => tmail.from[0],
        :message_id => tmail.message_id,
        :subject => subject ? subject : NKF::nkf("-w", tmail.subject),
        :mail_body => body ? body : NKF::nkf("-w", tmail.body)
      })
  end

  # 検索条件生成（問合せ詳細画面用）
  def self.create_condition_for_inquiry(inquiry_id, time_now = Time.now)
    where = Condition.block do |c|
      c.filter(:ignore_blank)
      # メール区分の条件
      c.and do |mail_div_q|
        mail_div_q.or(:mail_div, MailTemplate.mail_type_div_id_by_key(:inquiry))
        mail_div_q.or(:mail_div, MailTemplate.mail_type_div_id_by_key(:reply))
      end
      # お問合せ番号の条件
      c.and(:inquiry_id, inquiry_id)
      # 論理削除の条件
      c.and do |c4|
        c4.or("sql", "mail_deliveries.deleted_at IS NULL")
        c4.or('mail_deliveries.deleted_at', '>', time_now.strftime('%Y-%m-%d %H:%M:%S'))
      end
    end
  end

  #
  # 検索フォーム
  #
  class SearchConditionForm < ActiveForm
    attr_accessor :mail_div, :deliveried_at_from, :deliveried_at_to, :disp_count, :inquiry_id,
      :user_code, :name, :email, :member_div

    # 日付フォーマット
    validates_format_of :deliveried_at_from, :with => /^\d{4}\/\d{1,2}\/\d{1,2}$/, :message => :EM070001, :if => :deliveried_at_from_unempty?
    validates_format_of :deliveried_at_to, :with => /^\d{4}\/\d{1,2}\/\d{1,2}$/, :message => :EM070001, :if => :deliveried_at_to_unempty?

    # deliveried_at_fromに値がある場合trueをかえします。
    def deliveried_at_from_unempty?
      !deliveried_at_from.blank?
    end

    # deliveried_at_toに値がある場合trueをかえします。
    def deliveried_at_to_unempty?
      !deliveried_at_to.blank?
    end

    # 日付の存在チェック
    def validate
      if deliveried_at_from_unempty?
        _date = deliveried_at_from.split('/')
        unless Date.exist?(_date[0].to_i, _date[1].to_i, _date[2].to_i)
          errors.add(:deliveried_at_from, :EM990007)
        end
      end
      if deliveried_at_to_unempty?
        _date = deliveried_at_to.split('/')
        unless Date.exist?(_date[0].to_i, _date[1].to_i, _date[2].to_i)
          errors.add(:deliveried_at_to, :EM990007)
        end
      end
    end

    # 日付をTime型に変換する（日付が指定されなければnilを返す）
    def deliveried_at_from_time
      return nil if deliveried_at_from.blank?
      start_time_str = "#{self.deliveried_at_from} 00:00:00"
      return Time.parse(start_time_str)
    end
    
    def deliveried_at_to_time
      return nil if deliveried_at_to.blank?
      end_time_str = "#{self.deliveried_at_to} 23:59:59"
      return Time.parse(end_time_str)
    end
  end
end
